@@ -31,15 +31,15 @@
 #include <QHBoxLayout>
 #include <QAction>
 #include <QMenu>
-#include <Qt3Support/Q3ListView>
-#include <Qt3Support/Q3Header>
 #include <QDebug>
+#include <QTreeView>
+#include <QHeaderView>
 
 #include "traceitemview.h"
 #include "stackbrowser.h"
-#include "functionitem.h"
 #include "costlistitem.h"
 #include "globalconfig.h"
+#include "functionlistmodel.h"
 
 
 FunctionSelection::FunctionSelection( TopLevelBase* top,
@@ -49,6 +49,7 @@ FunctionSelection::FunctionSelection( TopLevelBase* top,
   _group = 0;
   _inSetGroup = false;
   _inSetFunction = false;
+  _functionListSortOrder = Qt::DescendingOrder;
 
   setTitle(tr("Function Profile"));
 
@@ -75,22 +76,35 @@ FunctionSelection::FunctionSelection( TopLevelBase* top,
   vboxLayout->setMargin(3);
   vboxLayout->addLayout(hboxLayout);
 
-  groupList = new Q3ListView(this);
-  groupList->addColumn(tr("Self"));
-  groupList->addColumn(tr("Group"));
-  groupList->header()->setClickEnabled(true);
-  groupList->header()->setResizeEnabled(true);
+  groupList = new QTreeWidget(this);
+  QStringList groupHeader;
+  groupHeader << tr("Self") << tr("Group");
+  groupList->setHeaderLabels(groupHeader);
+  groupList->header()->setClickable(true);
+  groupList->header()->setSortIndicatorShown(false);
+  groupList->header()->stretchLastSection();
+  groupList->setIconSize(QSize(99,99));
   groupList->setMaximumHeight(150);
+  groupList->setRootIsDecorated(false);
+  groupList->setUniformRowHeights(true);
+  groupList->sortByColumn(0, Qt::AscendingOrder);
   vboxLayout->addWidget(groupList);
 
-  functionList = new Q3ListView(this);
-  functionList->addColumn(tr("Incl."));
-  functionList->addColumn(tr("Self"));
-  functionList->addColumn(tr("Called"));
-  functionList->addColumn(tr("Function"));
-  functionList->addColumn(tr("Location"));
-  functionList->header()->setClickEnabled(true);
-  functionList->header()->setResizeEnabled(true);
+  functionListModel = new FunctionListModel();
+  functionListModel->setMaxCount(GlobalConfig::maxListCount());
+
+  functionList = new QTreeView(this);
+  functionList->setRootIsDecorated(false);
+  functionList->setAllColumnsShowFocus(true);
+  functionList->setContextMenuPolicy(Qt::CustomContextMenu);
+  functionList->setUniformRowHeights(true);
+  functionList->header()->setClickable(true);
+  functionList->header()->setSortIndicatorShown(false);
+  functionList->header()->setSortIndicator(0, Qt::DescendingOrder);
+  functionList->header()->setResizeMode(QHeaderView::Interactive);
+  // for columns 3 and 4 (all others get resized)
+  functionList->header()->setDefaultSectionSize(200);
+  functionList->setModel(functionListModel);
   vboxLayout->addWidget(functionList);
 
   // order has to match mapping in groupTypeSelected()
@@ -114,54 +128,28 @@ FunctionSelection::FunctionSelection( TopLevelBase* top,
 	  this, SLOT(searchReturnPressed()));
   searchEdit->setMinimumWidth(50);
 
-  // we start with desending cost sorting
-  functionList->setSorting(0,false);
-  functionList->setColumnAlignment(0, Qt::AlignRight);
-  functionList->setColumnAlignment(1, Qt::AlignRight);
-  functionList->setColumnAlignment(2, Qt::AlignRight);
-  functionList->setAllColumnsShowFocus(true);
-  // functionList->setShowSortIndicator(true);
-  // we can have very long function and location names
-  functionList->setColumnWidthMode(3, Q3ListView::Manual);
-  functionList->setColumnWidth(3, 200);
-  functionList->setColumnWidthMode(4, Q3ListView::Manual);
-  functionList->setColumnWidth(4, 200);
-
-  groupList->setSorting(0,false);
-  groupList->setColumnAlignment(0, Qt::AlignRight);
-  groupList->setAllColumnsShowFocus(true);
-  // groupList->setShowSortIndicator(true);
-  groupList->setResizeMode(Q3ListView::LastColumn);
-
-#if 0
-  // single click press activation
-  connect(functionList, SIGNAL(selectionChanged(Q3ListViewItem*)),
-          this, SLOT(functionActivated(Q3ListViewItem*)));
-  connect(functionList,
-	  SIGNAL(contextMenuRequested(Q3ListViewItem*, const QPoint &, int)),
-          this, SLOT(functionContext(Q3ListViewItem*, const QPoint &, int)));
-#else
   // single click release activation
-  connect(functionList, SIGNAL(selectionChanged(Q3ListViewItem*)),
-          this, SLOT(functionSelected(Q3ListViewItem*)));
-  connect(functionList, SIGNAL(clicked(Q3ListViewItem*)),
-	  this, SLOT(functionActivated(Q3ListViewItem*)));
-  connect(functionList, SIGNAL(returnPressed(Q3ListViewItem*)),
-	  this, SLOT(functionActivated(Q3ListViewItem*)));
-  connect(functionList,
-	  SIGNAL(contextMenuRequested(Q3ListViewItem*, const QPoint &, int)),
-          this, SLOT(functionContext(Q3ListViewItem*, const QPoint &, int)));
-#endif
+  connect(functionList, SIGNAL(clicked(QModelIndex)),
+          this, SLOT(functionActivated(QModelIndex)));
+  connect(functionList, SIGNAL(activated(QModelIndex)),
+          this, SLOT(functionActivated(QModelIndex)));
+  connect(functionList, SIGNAL(customContextMenuRequested(const QPoint &)),
+          this, SLOT(functionContext(const QPoint &)));
+  connect(functionList->header(), SIGNAL(sectionClicked(int)),
+          this, SLOT(functionHeaderClicked(int)));
 
-  connect(groupList, SIGNAL(selectionChanged(Q3ListViewItem*)),
-          this, SLOT(groupSelected(Q3ListViewItem*)));
-  connect(groupList, SIGNAL(doubleClicked(Q3ListViewItem*)),
-	  this, SLOT(groupDoubleClicked(Q3ListViewItem*)));
-  connect(groupList, SIGNAL(returnPressed(Q3ListViewItem*)),
-	  this, SLOT(groupDoubleClicked(Q3ListViewItem*)));
   connect(groupList,
-	  SIGNAL(contextMenuRequested(Q3ListViewItem*, const QPoint &, int)),
-          this, SLOT(groupContext(Q3ListViewItem*, const QPoint &, int)));
+          SIGNAL( currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
+          this, SLOT( groupSelected(QTreeWidgetItem*,QTreeWidgetItem*) ) );
+  connect(groupList, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
+          this, SLOT(groupDoubleClicked(QTreeWidgetItem*,int)));
+
+  groupList->setContextMenuPolicy(Qt::CustomContextMenu);
+  connect(groupList,
+          SIGNAL(customContextMenuRequested(const QPoint &) ),
+          this, SLOT(groupContext(const QPoint &)));
+  connect(groupList->header(),
+          SIGNAL(sectionClicked(int)), this, SLOT(groupHeaderClicked(int)));
 
   // start hidden
   groupList->hide();
@@ -186,26 +174,41 @@ QString FunctionSelection::whatsThis() const
 	"costs less than 1% are hidden on default.</p>");
 }
 
+void FunctionSelection::setData(TraceData* d)
+{
+  TraceItemView::setData(d);
+
+  _group = 0;
+  _groupSize.clear();
+  _hc.clear(GlobalConfig::maxListCount());
+  groupList->clear();
+  functionListModel->resetModelData(d, 0, QString(), 0);
+}
+
 void FunctionSelection::searchReturnPressed()
 {
   query(searchEdit->text());
 
-  Q3ListViewItem* item;
+  QTreeWidgetItem* item;
   if (_groupType != ProfileContext::Function) {
       // if current group not matching, select first matching group
       item  = groupList->currentItem();
-      if (!item || !item->isVisible()) {
-	  item  = groupList->firstChild();
-	  for (;item;item = item->nextSibling())
-	      if (item->isVisible()) break;
-	  if (!item) return;
+      if (!item || item->isHidden()) {
+          int i;
+          item = 0;
+          for (i=0; i<groupList->topLevelItemCount(); i++) {
+              item = groupList->topLevelItem(i);
+              if (!item->isHidden()) break;
+          }
+          if (!item) return;
 
-	  setGroup(((CostListItem*)item)->costItem());
-	  return;
+          setGroup(((CostListItem*)item)->costItem());
+          return;
       }
   }
-
-  functionActivated(functionList->firstChild());
+  // activate top function in functionList
+  selectTopFunction();
+  functionList->setFocus();
 }
 
 // trigger the query after some delay, dependent on length
@@ -215,7 +218,8 @@ void FunctionSelection::searchChanged(const QString& q)
   int ms = 100;
   if (q.length()<5) ms = 200;
   if (q.length()<2) ms = 300;
-  _searchTimer.start(ms,true);
+  _searchTimer.setSingleShot(true);
+  _searchTimer.start(ms);
 }
 
 void FunctionSelection::queryDelayed()
@@ -223,49 +227,51 @@ void FunctionSelection::queryDelayed()
   query(_searchDelayed);
 }
 
-void FunctionSelection::functionContext(Q3ListViewItem* i,
-					const QPoint & p, int c)
+void FunctionSelection::functionContext(const QPoint & p)
 {
     QMenu popup;
     TraceFunction* f = 0;
 
     QAction* activateFunctionAction = 0;
-    if (i) {
-	f = ((FunctionItem*) i)->function();
+    QModelIndex i = functionList->indexAt(p);
+    if (i.isValid()) {
+        f = functionListModel->function(i);
 	if (f) {
 	    QString menuText = tr("Go to '%1'").arg(GlobalConfig::shortenSymbol(f->prettyName()));
 	    activateFunctionAction = popup.addAction(menuText);
 	    popup.addSeparator();
 	}
+        if ((i.column() == 0) || (i.column() == 1)) {
+            addEventTypeMenu(&popup,false);
+            popup.addSeparator();
+        }
     }
 
-    if ((c == 0) || (c == 1)) {
-	addEventTypeMenu(&popup,false);
-	popup.addSeparator();
+    addGroupMenu(&popup);
+    popup.addSeparator();
+    addGoMenu(&popup);
+
+    QPoint pDiff = QPoint(0, functionList->header()->height());
+    QAction* a = popup.exec(functionList->mapToGlobal(p + pDiff));
+    if (a == activateFunctionAction)
+	activated(f);
+}
+
+void FunctionSelection::groupContext(const QPoint & p)
+{
+    QMenu popup;
+
+    int c = groupList->columnAt(p.x());
+    if (c == 0) {
+        addEventTypeMenu(&popup,false);
+        popup.addSeparator();
     }
     addGroupMenu(&popup);
     popup.addSeparator();
     addGoMenu(&popup);
 
-    QAction* a = popup.exec(p);
-    if (a == activateFunctionAction)
-	activated(f);
-}
-
-void FunctionSelection::groupContext(Q3ListViewItem* /*i*/,
-				     const QPoint & p, int c)
-{
-  QMenu popup;
-
-  if (c == 0) {
-    addEventTypeMenu(&popup,false);
-    popup.addSeparator();
-  }
-  addGroupMenu(&popup);
-  popup.addSeparator();
-  addGoMenu(&popup);
-
-  popup.exec(p);
+    QPoint headerSize = QPoint(0, groupList->header()->height());
+    popup.exec(groupList->mapToGlobal(p + headerSize));
 }
 
 void FunctionSelection::addGroupAction(QMenu* m,
@@ -346,6 +352,22 @@ CostItem* FunctionSelection::canShow(CostItem* i)
 }
 
 
+void FunctionSelection::selectFunction(TraceFunction* f,
+                                       bool ensureVisible)
+{
+    QModelIndex i = functionListModel->indexForFunction(f, true);
+    if (!i.isValid()) return;
+
+    if (ensureVisible)
+        functionList->scrollTo(i, QAbstractItemView::EnsureVisible);
+
+    _inSetFunction = true;
+    QModelIndex last = functionListModel->index(i.row(), 4);
+    QItemSelection s(i, last);
+    functionList->selectionModel()->select(s, QItemSelectionModel::ClearAndSelect);
+    _inSetFunction = false;
+}
+
 void FunctionSelection::doUpdate(int changeType, bool)
 {
     // Special case ?
@@ -354,6 +376,27 @@ void FunctionSelection::doUpdate(int changeType, bool)
     // we do not show cost 2 at all...
     if (changeType == eventType2Changed) return;
 
+    if (changeType == eventTypeChanged) {
+        int i;
+        groupList->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+        // need to disable sorting! Otherwise each change of shown cost
+        // reorders list and changes order returned by topLevelItem()
+        groupList->setSortingEnabled(false);
+        for (i=0; i<groupList->topLevelItemCount(); i++) {
+            CostListItem* item = (CostListItem*) groupList->topLevelItem(i);
+            item->setEventType(_eventType);
+        }
+        groupList->header()->setResizeMode(0, QHeaderView::Interactive);
+        groupList->setSortingEnabled(true);
+        groupList->header()->setSortIndicatorShown(false);
+
+        functionListModel->setEventType(_eventType);
+        // previous line resets the model: reselect active item
+        selectFunction(dynamic_cast<TraceFunction*>(_activeItem));
+        setCostColumnWidths();
+        return;
+    }
+
     if (changeType == activeItemChanged) {
 	if (_activeItem ==0) {
 	    functionList->clearSelection();
@@ -372,15 +415,13 @@ void FunctionSelection::doUpdate(int changeType, bool)
 	TraceFunction* f = (TraceFunction*) _activeItem;
 
 	// if already current, nothing to do
-	Q3ListViewItem* i = functionList->currentItem();
-	if (i && (((FunctionItem*)i)->function() == f)) {
-	    functionList->setSelected(i,true);
+        QModelIndex i = functionList->currentIndex();
+        if (functionListModel->function(i) == f) {
 	    return;	    
 	}
 
-	// reset searchEdit (as not activated from this view)
-	_searchString = QString();
-	query(QString::null);	//krazy:exclude=nullstrassign for old broken gcc
+        // reset search (as not activated from this view)
+        query(QString::null);	//krazy:exclude=nullstrassign for old broken gcc
 
 	// select cost item group of function
 	switch(_groupType) {
@@ -392,20 +433,7 @@ void FunctionSelection::doUpdate(int changeType, bool)
 	    break;
 	}
 
-	Q3ListViewItem* item  = functionList->firstChild();
-	for (;item;item = item->nextSibling())
-	    if (((FunctionItem*)item)->function() == f)
-		break;
-
-	if (!item)
-	    item = new FunctionItem(functionList, f, _eventType, _groupType);
-
-	functionList->ensureItemVisible(item);
-	// prohibit signalling of a function selection
-	_inSetFunction = true;
-	functionList->setSelected(item, true);
-	_inSetFunction = false;
-
+        selectFunction(f);
 	return;
     }
 
@@ -460,17 +488,20 @@ void FunctionSelection::setGroup(TraceCostItem* g)
   if (g == _group) return;
   _group = g;
 
-  Q3ListViewItem* item  = groupList->firstChild();
-  for (;item;item = item->nextSibling())
-    if (((CostListItem*)item)->costItem() == g)
-      break;
+  QTreeWidgetItem* item = 0;
+  int i;
+  for (i=0; i < groupList->topLevelItemCount(); i++) {
+      item = groupList->topLevelItem(i);
+      if (((CostListItem*)item)->costItem() == g)
+          break;
+  }
 
   if (item) {
-    groupList->ensureItemVisible(item);
+    groupList->scrollToItem(item);
     // prohibit signalling of a group selection
     _inSetGroup = true;
     _group = 0;
-    groupList->setSelected(item, true);
+    groupList->setCurrentItem(item);
     _inSetGroup = false;
   }
   else
@@ -485,21 +516,20 @@ void FunctionSelection::refresh()
     // make cost columns as small as possible:
     // the new functions make them as wide as needed
     groupList->setColumnWidth(0, 50);
+    groupList->headerItem()->setText(1, ProfileContext::i18nTypeName(_groupType));
 
-    groupList->setColumnText(1, ProfileContext::i18nTypeName(_groupType));
+    functionListModel->setMaxCount(GlobalConfig::maxListCount());
 
     if (!_data || _data->parts().count()==0) {
-	functionList->clear();
-
-	// this clears all other lists
-	functionList->setSelected(functionList->firstChild(), true);
+        functionListModel->resetModelData(0, 0, QString(), 0);
+        selectTopFunction();
 	return;
     }
 
+
   TraceObjectMap::Iterator oit;
   TraceClassMap::Iterator cit;
   TraceFileMap::Iterator fit;
-  Q3ListViewItem *i = 0, *item = 0, *fitem = 0;
 
   // Fill up group list.
   // Always show group of current function, even if cost below low limit.
@@ -507,12 +537,6 @@ void FunctionSelection::refresh()
 
   _hc.clear(GlobalConfig::maxListCount());
 
-  TraceCostItem *group;
-
-  // update group from _activeItem if possible
-  if (_activeItem && (_activeItem->type() == _groupType))
-    _group = (TraceCostItem*) _activeItem;
-
   switch(_groupType) {
   case ProfileContext::Object:
 
@@ -538,8 +562,7 @@ void FunctionSelection::refresh()
   case ProfileContext::FunctionCycle:
     {
       // add all cycles
-      TraceFunctionCycleList l =  _data->functionCycles();
-      for (group=l.first();group;group=l.next())
+      foreach(TraceCostItem *group, _data->functionCycles())
 	_hc.addCost(group, group->subCost(_eventType));
     }
 
@@ -547,96 +570,56 @@ void FunctionSelection::refresh()
 
   default:
     {
-      Q3ListViewItem* oldItem = functionList->selectedItem();
-      TraceFunction* oldFunction = 0;
-      int oldPos = 0;
-      if (oldItem) {
-	oldFunction = ((FunctionItem*)oldItem)->function();
-	oldPos = oldItem->itemPos();
-	oldPos -= functionList->contentsY();
-	if (oldPos < 0 || oldPos > functionList->height())
-	  oldFunction = 0;
-      }
-
-      functionList->clear();
+      _group = 0;
+      functionListModel->resetModelData(_data, _group, _searchString, _eventType);
+      selectFunction(dynamic_cast<TraceFunction*>(_activeItem));
       setCostColumnWidths();
-
-      if (0) qDebug("Function %s at %d, Item %p",
-		    oldFunction ? oldFunction->name().ascii() : "-",
-		    oldPos, (void*)oldItem);
-
-      TraceFunctionMap::Iterator it;
-      TraceFunction *f;
-      i = 0;
-      fitem = 0;
-      for ( it = _data->functionMap().begin();
-	    it != _data->functionMap().end(); ++it )
-	_hc.addCost(&(*it), (*it).inclusive()->subCost(_eventType));
-
-      TraceFunctionCycleList l =  _data->functionCycles();
-      for (f=l.first();f;f=l.next())
-	_hc.addCost(f, f->inclusive()->subCost(_eventType));
-
-      if (_activeItem &&
-	  ((_activeItem->type() == ProfileContext::Function) ||
-	   (_activeItem->type() == ProfileContext::FunctionCycle)))
-	fitem = new FunctionItem(functionList, (TraceFunction*)_activeItem,
-				 _eventType, _groupType);
-
-      for(int i=0;i<_hc.realCount();i++) {
-	f = (TraceFunction*)_hc[i];
-	if (f == _activeItem) continue;
-	new FunctionItem(functionList, f, _eventType, _groupType);
-      }
-      if (_hc.hasMore()) {
-	// a placeholder for all the cost items skipped ...
-	new FunctionItem(functionList, _hc.count() - _hc.maxSize(),
-			 (TraceFunction*)_hc[_hc.maxSize()-1], _eventType);
-      }
-      functionList->sort();
-
-      if (fitem && oldFunction) {
-        _inSetFunction = true;
-	functionList->setSelected(fitem, true);
-        _inSetFunction = false;
-	int newPos = functionList->itemPos(fitem) - functionList->contentsY();
-	functionList->scrollBy(0, newPos-oldPos);
-      }
-      else if (fitem) {
-	functionList->ensureItemVisible(fitem);
-        _inSetFunction = true;
-	functionList->setSelected(fitem, true);
-        _inSetFunction = false;
-      }
-      else
-	functionList->clearSelection();
-
       return;
     }
   }
 
+  // update group from _activeItem if possible
+  if (_activeItem && (_activeItem->type() == _groupType))
+    _group = (TraceCostItem*) _activeItem;
+
+  QTreeWidgetItem *item = 0, *activeItem = 0;
+  QList<QTreeWidgetItem*> items;
+
   // we always put group of active item in list, even if
   // it would be skipped because of small costs
-  if (_group)
-    item = new CostListItem(groupList, _group, _eventType);
+  if (_group) {
+    activeItem = new CostListItem(groupList, _group, _eventType);
+    items.append(activeItem);
+  }
 
-  for(int i=0;i<_hc.realCount();i++) {
-    group = (TraceCostItem*)_hc[i];
+  for(int i=0; i<_hc.realCount(); i++) {
+    TraceCostItem *group = (TraceCostItem*)_hc[i];
     // do not put group of active item twice into list
     if (group == _group) continue;
-    new CostListItem(groupList, group, _eventType);
+    item = new CostListItem(groupList, group, _eventType);
+    items.append(item);
   }
   if (_hc.hasMore()) {
       // a placeholder for all the cost items skipped ...
-    new CostListItem(groupList, _hc.count() - _hc.maxSize(),
-		     (TraceCostItem*)_hc[_hc.maxSize()-1], _eventType);
+      item = new CostListItem(groupList, _hc.count() - _hc.maxSize(),
+                              (TraceCostItem*)_hc[_hc.maxSize()-1], _eventType);
+      items.append(item);
   }
-  groupList->sort();
-  if (item) {
-    groupList->ensureItemVisible(item);
+
+  groupList->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+  groupList->setSortingEnabled(false);
+  groupList->addTopLevelItems(items);
+  groupList->setSortingEnabled(true);
+  // always reset to cost sorting
+  groupList->sortByColumn(0, Qt::DescendingOrder);
+  groupList->header()->setSortIndicatorShown(false);
+  groupList->header()->setResizeMode(0, QHeaderView::Interactive);
+
+  if (activeItem) {
+    groupList->scrollToItem(activeItem);
     _inSetGroup = true;
     _group = 0;
-    groupList->setSelected(item, true);
+    groupList->setCurrentItem(activeItem);
     _inSetGroup = false;
   }
   else
@@ -644,7 +627,7 @@ void FunctionSelection::refresh()
 }
 
 
-void FunctionSelection::groupSelected(Q3ListViewItem* i)
+void FunctionSelection::groupSelected(QTreeWidgetItem* i, QTreeWidgetItem*)
 {
   if (!i) return;
   if (!_data) return;
@@ -654,68 +637,10 @@ void FunctionSelection::groupSelected(Q3ListViewItem* i)
   if (g == _group) return;
   _group = g;
 
-  TraceFunctionList list;
-
-  switch(g->type()) {
-  case ProfileContext::Object:
-    list = ((TraceObject*)g)->functions();
-    break;
-  case ProfileContext::Class:
-    list = ((TraceClass*)g)->functions();
-    break;
-  case ProfileContext::File:
-    list = ((TraceFile*)g)->functions();
-    break;
-  case ProfileContext::FunctionCycle:
-    list = ((TraceFunctionCycle*)g)->members();
-    break;
-  default:
-    return;
-  }
-
-  functionList->clear();
+  functionListModel->resetModelData(_data, g, _searchString, _eventType);
+  selectFunction(dynamic_cast<TraceFunction*>(_activeItem));
   setCostColumnWidths();
 
-  double total;
-  if (GlobalConfig::showExpanded())
-      total = (double) g->subCost(_eventType);
-  else
-      total = (double) _data->subCost(_eventType);
-
-  QRegExp re(_searchString, false, true);
-
-  FunctionItem* fitem = 0;
-  TraceFunction *f;
-  _hc.clear(GlobalConfig::maxListCount());
-  for (f=list.first();f;f=list.next()) {
-    if (re.search(f->prettyName())<0) continue;
-
-    _hc.addCost(f, f->inclusive()->subCost(_eventType));
-    if (_activeItem == f)
-      fitem = new FunctionItem(functionList, (TraceFunction*)_activeItem,
-			       _eventType, _groupType);
-  }
-
-  for(int i=0;i<_hc.realCount();i++) {
-    if (_activeItem == (TraceFunction*)_hc[i]) continue;
-    new FunctionItem(functionList, (TraceFunction*)_hc[i],
-		     _eventType, _groupType);
-  }
-
-  if (_hc.hasMore()) {
-    // a placeholder for all the functions skipped ...
-    new FunctionItem(functionList, _hc.count() - _hc.maxSize(),
-		     (TraceFunction*)_hc[_hc.maxSize()-1], _eventType);
-  }
-  functionList->sort();
-
-  if (fitem) {
-    functionList->ensureItemVisible(fitem);
-    _inSetFunction = true;
-    functionList->setSelected(fitem, true);
-    _inSetFunction = false;
-  }
-
   // Do not emit signal if cost item was changed programatically
   if (!_inSetGroup) {
       if (_topLevel)
@@ -723,7 +648,7 @@ void FunctionSelection::groupSelected(Q3ListViewItem* i)
   }
 }
 
-void FunctionSelection::groupDoubleClicked(Q3ListViewItem* i)
+void FunctionSelection::groupDoubleClicked(QTreeWidgetItem* i, int)
 {
   if (!i) return;
   if (!_data) return;
@@ -736,43 +661,29 @@ void FunctionSelection::groupDoubleClicked(Q3ListViewItem* i)
   activated(g);
 }
 
+void FunctionSelection::groupHeaderClicked(int col)
+{
+    groupList->sortByColumn(col, Qt::DescendingOrder);
+}
 
 TraceCostItem* FunctionSelection::group(QString s)
 {
-  Q3ListViewItem *item;
-  item  = groupList->firstChild();
-  for(;item;item = item->nextSibling())
-    if (((CostListItem*)item)->costItem()->name() == s)
-      return ((CostListItem*)item)->costItem();
+    int i;
+    for (i=0; i<groupList->topLevelItemCount(); i++) {
+        CostListItem* item = (CostListItem*) groupList->topLevelItem(i);
+        if (item->costItem()->name() == s)
+          return item->costItem();
+    }
 
-  return 0;
+    return 0;
 }
 
 
-
-void FunctionSelection::functionSelected(Q3ListViewItem* i)
+void FunctionSelection::functionActivated(const QModelIndex& i)
 {
-  if (!i) return;
   if (!_data) return;
 
-  TraceFunction* f = ((FunctionItem*) i)->function();
-  if (!f) return;
-
-  //qDebug("FunctionSelection::functionSelected %s", f->name().ascii());
-
-  // Do not emit signal if function was changed programatically
-  if (!_inSetFunction) {
-      _selectedItem = f;
-      selected(f);
-  }
-}
-
-void FunctionSelection::functionActivated(Q3ListViewItem* i)
-{
-  if (!i) return;
-  if (!_data) return;
-  TraceFunction* f = ((FunctionItem*) i)->function();
-
+  TraceFunction* f = functionListModel->function(i);
   if (!f) return;
 
   if (!_inSetFunction)
@@ -781,14 +692,14 @@ void FunctionSelection::functionActivated(Q3ListViewItem* i)
 
 void FunctionSelection::updateGroupSizes(bool hideEmpty)
 {
-  Q3ListViewItem* item  = groupList->firstChild();
-  for (;item;item = item->nextSibling()) {
-    CostListItem* i = (CostListItem*)item;
-    int size = (_groupSize.contains(i->costItem())) ?
- 	_groupSize[i->costItem()] : -1;    
-    i->setSize(size);
-    i->setVisible(!hideEmpty || (size>0));
-  }
+    int i;
+    for (i=0; i<groupList->topLevelItemCount(); i++) {
+        CostListItem* item = (CostListItem*) groupList->topLevelItem(i);
+        int size = (_groupSize.contains(item->costItem())) ?
+                   _groupSize[item->costItem()] : -1;
+        item->setSize(size);
+        item->setHidden(hideEmpty && (size<0));
+    }
 }
 
 void FunctionSelection::query(QString query)
@@ -807,7 +718,7 @@ void FunctionSelection::query(QString query)
   }
   _searchString = query;
 
-  QRegExp re(query, false, true);
+  QRegExp re(query, Qt::CaseInsensitive, QRegExp::Wildcard);
   _groupSize.clear();
 
   TraceFunction* f = 0;
@@ -819,7 +730,7 @@ void FunctionSelection::query(QString query)
   for ( it = _data->functionMap().begin();
 	it != _data->functionMap().end(); ++it ) {
     f = &(*it);
-    if (re.search(f->prettyName())>=0) {
+    if (re.indexIn(f->prettyName())>=0) {
       if (_group) {
 	if (_groupType==ProfileContext::Object) {
 	  if (_groupSize.contains(f->object()))
@@ -855,61 +766,51 @@ void FunctionSelection::query(QString query)
   }
   updateGroupSizes(true);
 
-  FunctionItem *fi, *item = 0;
-
-  functionList->clear();
+  functionListModel->resetModelData(_data, _group, _searchString, _eventType);
+  selectFunction(dynamic_cast<TraceFunction*>(_activeItem));
   setCostColumnWidths();
-  for(int i=0;i<_hc.realCount();i++) {
-      fi = new FunctionItem(functionList, (TraceFunction*)_hc[i],
-			    _eventType, _groupType);
-      if (_activeItem == f) item = fi;
-  }
-  if (_hc.hasMore()) {
-      // a placeholder for all the functions skipped ...
-      new FunctionItem(functionList, _hc.count() - _hc.maxSize(),
-		       (TraceFunction*)_hc[_hc.maxSize()-1], _eventType);
-  }
-
-  functionList->sort();
-
-
-  if (item) {
-    functionList->ensureItemVisible(item);
-    _inSetFunction = true;
-    functionList->setSelected(item, true);
-    _inSetFunction = false;
-  }
-  else {
-    // this emits a function selection
-    functionList->setSelected(functionList->firstChild(), true);
-  }
 }
 
-bool FunctionSelection::setTopFunction()
+bool FunctionSelection::selectTopFunction()
 {
-  Q3ListViewItem* i = functionList->firstChild();
-  // this emits a function selection
-  functionList->setSelected(i, true);
-  functionActivated(i);
-  return i!=0;
+    QModelIndex i = functionListModel->index(0,0);
+    TraceFunction* f = functionListModel->function(i);
+
+    // pre-select before activation to not trigger a refresh of this view
+    _activeItem = f;
+    selectFunction(f);
+
+    functionActivated(i);
+
+    return (f!=0);
 }
 
 void FunctionSelection::setCostColumnWidths()
 {
-  if (_eventType && (_eventType->subCost(_data->callMax())>0) ) {
-    functionList->setColumnWidthMode(0, Q3ListView::Maximum);
-    functionList->setColumnWidth(0,50);
-    functionList->setColumnWidthMode(2, Q3ListView::Maximum);
-    functionList->setColumnWidth(2,50);
-  }
-  else {
-    functionList->setColumnWidthMode(0, Q3ListView::Manual);
-    functionList->setColumnWidth(0,0);
-    functionList->setColumnWidthMode(2, Q3ListView::Manual);
-    functionList->setColumnWidth(2,0);
-  }
+    functionList->resizeColumnToContents(1);
 
-  functionList->setColumnWidth(1, 50);
+    if (_eventType && (_eventType->subCost(_data->callMax())>0) ) {
+        functionList->resizeColumnToContents(0);
+        functionList->resizeColumnToContents(2);
+    }
+    else {
+        functionList->header()->resizeSection(0, 0);
+        functionList->header()->resizeSection(2, 0);
+    }
 }
 
+void FunctionSelection::functionHeaderClicked(int col)
+{
+    if ((_functionListSortOrder== Qt::AscendingOrder) || (col<3))
+        _functionListSortOrder = Qt::DescendingOrder;
+    else
+        _functionListSortOrder = Qt::AscendingOrder;
+
+    functionList->sortByColumn(col, _functionListSortOrder);
+    selectFunction(dynamic_cast<TraceFunction*>(_activeItem), false);
+    setCostColumnWidths();
+}
+
+
+
 #include "functionselection.moc"
