@@ -659,6 +659,12 @@ void EditorTab::setupActions()
     connect( m_syncView, SIGNAL(signalNextChangedAvailable(bool)),action,SLOT(setEnabled(bool)) );
     m_syncView->addAction(action);
 
+    action = sync1->addAction("merge_nextapproved",m_syncView,SLOT(gotoNextChangedApproved()));
+    action->setText(i18nc("@action:inmenu","Next different approved"));
+    action->setShortcut(Qt::ALT+Qt::META+Qt::Key_Down);
+    connect( m_syncView, SIGNAL(signalNextChangedAvailable(bool)),action,SLOT(setEnabled(bool)) );
+    m_syncView->addAction(action);
+
     action = sync1->addAction("merge_accept",m_syncView,SLOT(mergeAccept()));
     action->setText(i18nc("@action:inmenu","Copy from merging source"));
     action->setShortcut(Qt::ALT+Qt::Key_Return);
@@ -801,7 +807,7 @@ bool EditorTab::fileOpen(KUrl url, KUrl baseUrl, bool silent)
     {
         //Prevent crashes
         Project::instance()->model()->weaver()->suspend();
-        url=KFileDialog::getOpenFileName(baseUrl, "text/x-gettext-translation text/x-gettext-translation-template application/x-xliff",SettingsController::instance()->mainWindowPtr());
+        url=KFileDialog::getOpenFileName(baseUrl, "text/x-gettext-translation text/x-gettext-translation-template application/x-xliff application/x-linguist",SettingsController::instance()->mainWindowPtr());
         Project::instance()->model()->weaver()->resume();
         //TODO application/x-xliff, windows: just extensions
         //originalPath=url.path(); never used
@@ -976,7 +982,7 @@ void EditorTab::gotoEntry()
     }
 }
 
-void EditorTab::gotoEntry(DocPosition pos,int selection)
+void EditorTab::gotoEntry(DocPosition pos, int selection)
 {
     //specially for dbus users
     if (pos.entry>=m_catalog->numberOfEntries()||pos.entry<0)
@@ -1005,8 +1011,7 @@ void EditorTab::gotoEntry(DocPosition pos,int selection)
     if (pos.part==DocPosition::UndefPart)
         m_currentPos.part=DocPosition::Target;
 
-    QTime time;
-    time.start();
+    //QTime time; time.start();
 
     if (newEntry)
     {
@@ -1412,6 +1417,8 @@ bool EditorTab::entryReady(int entry){return m_catalog->isApproved(entry);}
 void EditorTab::addEntryNote(int entry, const QString& note){m_notesView->addNote(entry, note);}
 void EditorTab::addTemporaryEntryNote(int entry, const QString& note){m_notesView->addTemporaryEntryNote(entry, note);}
 
+void EditorTab::addAlternateTranslation(int entry, const QString& translation){m_altTransView->addAlternateTranslation(entry, translation);}
+void EditorTab::addTemporaryAlternateTranslation(int entry, const QString& translation){m_altTransView->addAlternateTranslation(entry, translation);}
 void EditorTab::attachAlternateTranslationFile(const QString& path){m_altTransView->attachAltTransFile(path);}
 
 void EditorTab::setEntryTarget(int entry, int form, const QString& content)
