@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2010                                                *
+ *  copyright (C) 2002-2011                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -13,10 +13,10 @@
 #include "entity.h"
 #include "umlentityattributelist.h"
 
-#include <kdebug.h>
 #include <klocale.h>
 
 #include <QtCore/QList>
+#include <QtCore/QTextStream>
 
 PostgreSQLWriter::PostgreSQLWriter()
 {
@@ -29,9 +29,9 @@ PostgreSQLWriter::~PostgreSQLWriter()
 /**
  * Returns "PostgreSQL".
  */
-Uml::Programming_Language PostgreSQLWriter::language() const
+Uml::ProgrammingLanguage PostgreSQLWriter::language() const
 {
-    return Uml::pl_PostgreSQL;
+    return Uml::ProgrammingLanguage::PostgreSQL;
 }
 
 /**
@@ -69,10 +69,10 @@ QStringList PostgreSQLWriter::defaultDatatypes()
     l.append( "real" );
     l.append( "serial" );
     l.append( "smallint" );
-    l.append( "time without timezone" );
-    l.append( "time with timezone" );
-    l.append( "timestamp without timezone" );
-    l.append( "time with timezone" );
+    l.append( "time without time zone" );
+    l.append( "time with time zone" );
+    l.append( "timestamp without time zone" );
+    l.append( "timestamp with time zone" );
 
     return l;
 }
@@ -93,7 +93,7 @@ void PostgreSQLWriter::printAutoIncrements(QTextStream& sql, UMLEntityAttributeL
 
         QString sequenceName;
         // we keep the sequence name as entityName + '_' + entityAttributeName
-        sequenceName = m_pEntity->getName() + '_' + ea->getName();
+        sequenceName = m_pEntity->name() + '_' + ea->name();
 
         // we assume the sequence count starts with 1 and interval is 1 too
         // change the values when we start supporting different start values and
@@ -105,15 +105,15 @@ void PostgreSQLWriter::printAutoIncrements(QTextStream& sql, UMLEntityAttributeL
         sql<<m_endl;
 
         // alter the table column ( set not null )
-        sql<<"ALTER TABLE "<<cleanName( m_pEntity->getName() )
-           <<" ALTER COLUMN "<<cleanName( ea->getName() )
+        sql<<"ALTER TABLE "<<cleanName( m_pEntity->name() )
+           <<" ALTER COLUMN "<<cleanName( ea->name() )
            <<" SET NOT NULL ";
 
         sql<<m_endl;
 
         // alter the table column
-        sql<<"ALTER TABLE "<<cleanName( m_pEntity->getName() )
-           <<" ALTER COLUMN "<<cleanName( ea->getName() )
+        sql<<"ALTER TABLE "<<cleanName( m_pEntity->name() )
+           <<" ALTER COLUMN "<<cleanName( ea->name() )
            <<" SET DEFAULT nextval('"<<cleanName( sequenceName )
            <<"');";
 
