@@ -4,31 +4,29 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2008                                                *
+ *  copyright (C) 2002-2011                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 // own header
 #include "settingsdlg.h"
 
-// qt includes
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QGridLayout>
-
-// kde includes
-#include <kvbox.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-
 // app includes
+#include "codeimportoptionspage.h"
 #include "codegenoptionspage.h"
+#include "umlwidgetstylepage.h"
 #include "codevieweroptionspage.h"
 #include "dialog_utils.h"
-#include "model_utils.h"
+#include "debug_utils.h"
 #include "icon_utils.h"
 
+#include <kvbox.h>
+
+//TODO don't do that, but it's better than hardcoded in the functions body
+#define FILL_COLOR QColor(255, 255, 192) 
+#define LINK_COLOR Qt::red
+#define TEXT_COLOR Qt::black
+
 
 SettingsDlg::SettingsDlg( QWidget * parent, Settings::OptionState *state )
         : KPageDialog( parent)
@@ -46,6 +44,7 @@ SettingsDlg::SettingsDlg( QWidget * parent, Settings::OptionState *state )
     setupFontPage();
     setupUIPage();
     setupClassPage();
+    setupCodeImportPage();
     setupCodeGenPage();
     setupCodeViewerPage(state->codeViewerState);
     connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
@@ -59,8 +58,11 @@ SettingsDlg::~SettingsDlg()
 
 void SettingsDlg::setupUIPage()
 {
+    // FIXME: merge with UMLWidgetStylePage
     //setup UI page
-    KVBox * page = new KVBox();
+    QWidget * page = new QWidget();
+    QVBoxLayout* uiPageLayout = new QVBoxLayout(page);
+    
     pageUserInterface = new KPageWidgetItem( page,i18n("User Interface"));
     pageUserInterface->setHeader( i18n("User Interface Settings") );
     pageUserInterface->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_UserInterface) );
@@ -70,46 +72,87 @@ void SettingsDlg::setupUIPage()
     QGridLayout * colorLayout = new QGridLayout( m_UiWidgets.colorGB );
     colorLayout->setSpacing( spacingHint() );
     colorLayout->setMargin( fontMetrics().height() );
+    uiPageLayout->addWidget(m_UiWidgets.colorGB);
+    
+    uiPageLayout->addItem(new QSpacerItem(0, 20, QSizePolicy::Minimum, QSizePolicy::Expanding));
 
-    m_UiWidgets.lineColorL = new QLabel( i18n("Line color:"), m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.lineColorL, 0, 0 );
+    m_UiWidgets.textColorCB = new QCheckBox( i18n("Custom text color:"), m_UiWidgets.colorGB );
+    colorLayout->addWidget( m_UiWidgets.textColorCB, 0, 0 );
+
+    m_UiWidgets.textColorB = new KColorButton( m_pOptionState->uiState.textColor ,m_UiWidgets.colorGB);
+    //m_UiWidgets.lineColorB->setObjectName( m_UiWidgets.colorGB );
+    colorLayout->addWidget( m_UiWidgets.textColorB, 0, 1 );
+
+    m_UiWidgets.lineColorCB = new QCheckBox( i18n("Custom line color:"), m_UiWidgets.colorGB );
+    colorLayout->addWidget( m_UiWidgets.lineColorCB, 1, 0 );
 
     m_UiWidgets.lineColorB = new KColorButton( m_pOptionState->uiState.lineColor ,m_UiWidgets.colorGB);
     //m_UiWidgets.lineColorB->setObjectName( m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.lineColorB, 0, 1 );
+    colorLayout->addWidget( m_UiWidgets.lineColorB, 1, 1 );
 
-    m_UiWidgets.lineDefaultB = new QPushButton( i18n("D&efault Color"), m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.lineDefaultB, 0, 2 );
+//     m_UiWidgets.lineDefaultB = new QPushButton( i18n("D&efault Color"), m_UiWidgets.colorGB );
+//     colorLayout->addWidget( m_UiWidgets.lineDefaultB, 0, 2 );
 
-    m_UiWidgets.fillColorL = new QLabel( i18n("Fill color:"), m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.fillColorL, 1, 0 );
+    m_UiWidgets.fillColorCB = new QCheckBox( i18n("Custom fill color:"), m_UiWidgets.colorGB );
+    colorLayout->addWidget( m_UiWidgets.fillColorCB, 2, 0 );
 
     m_UiWidgets.fillColorB = new KColorButton( m_pOptionState->uiState.fillColor,m_UiWidgets.colorGB  );
-    //m_UiWidgets.fillColorB->setObjectName( m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.fillColorB, 1, 1 );
+    colorLayout->addWidget( m_UiWidgets.fillColorB, 2, 1 );
 
-    m_UiWidgets.fillDefaultB = new QPushButton( i18n("De&fault Color"), m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.fillDefaultB, 1, 2 );
+    m_UiWidgets.gridColorCB = new QCheckBox( i18n("Custom grid color:"), m_UiWidgets.colorGB );
+    colorLayout->addWidget(m_UiWidgets.gridColorCB , 3, 0 );
 
-    m_UiWidgets.lineWidthL = new QLabel( i18n("Line width:"), m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.lineWidthL, 2, 0 );
+    m_UiWidgets.gridColorB = new KColorButton( m_pOptionState->uiState.gridDotColor,m_UiWidgets.colorGB  );
+    colorLayout->addWidget(m_UiWidgets.gridColorB , 3, 1 );
+
+    m_UiWidgets.bgColorCB = new QCheckBox( i18n("Custom background color:"), m_UiWidgets.colorGB );
+    colorLayout->addWidget(m_UiWidgets.bgColorCB , 4, 0 );
+
+    m_UiWidgets.bgColorB = new KColorButton( m_pOptionState->uiState.backgroundColor,m_UiWidgets.colorGB  );
+    colorLayout->addWidget(m_UiWidgets.bgColorB , 4, 1 );
+
+    m_UiWidgets.lineWidthCB = new QCheckBox( i18n("Custom line width:"), m_UiWidgets.colorGB );
+    colorLayout->addWidget( m_UiWidgets.lineWidthCB, 5, 0 );
 
-    // Low-Limit: 0, High-Limit: 10, Step: 1, Initial-Val: m_pOptionState->uiState.lineWidth
-    // Number-Base: 10 ( decimal ), Parent: m_UiWidgets.colorGB
     m_UiWidgets.lineWidthB = new KIntSpinBox( 0, 10, 1, m_pOptionState->uiState.lineWidth, m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.lineWidthB, 2, 1 );
-
-    m_UiWidgets.lineWidthDefaultB = new QPushButton( i18n("D&efault Width"), m_UiWidgets.colorGB );
-    colorLayout->addWidget( m_UiWidgets.lineWidthDefaultB, 2, 2 );
-
+    colorLayout->addWidget( m_UiWidgets.lineWidthB, 5, 1 );
+    
     m_UiWidgets.useFillColorCB = new QCheckBox( i18n("&Use fill color"), m_UiWidgets.colorGB );
-    colorLayout->setRowStretch( 3, 2 );
-    colorLayout->addWidget( m_UiWidgets.useFillColorCB, 3, 0 );
+    //colorLayout->setRowStretch( 3, 2 );
+    colorLayout->addWidget( m_UiWidgets.useFillColorCB, 6, 0 );
     m_UiWidgets.useFillColorCB->setChecked( m_pOptionState->uiState.useFillColor );
 
     //connect button signals up
-    connect( m_UiWidgets.lineDefaultB, SIGNAL(clicked()), this, SLOT(slotLineBClicked()) );
-    connect( m_UiWidgets.fillDefaultB, SIGNAL(clicked()), this, SLOT(slotFillBClicked()) );
+    connect( m_UiWidgets.textColorCB, SIGNAL(toggled(bool)), this, SLOT(slotTextCBChecked(bool)) );
+    connect( m_UiWidgets.lineColorCB, SIGNAL(toggled(bool)), this, SLOT(slotLineCBChecked(bool)) );
+    connect( m_UiWidgets.fillColorCB, SIGNAL(toggled(bool)), this, SLOT(slotFillCBChecked(bool)) );
+    connect( m_UiWidgets.gridColorCB, SIGNAL(toggled(bool)), this, SLOT(slotGridCBChecked(bool)) );
+    connect( m_UiWidgets.bgColorCB, SIGNAL(toggled(bool)), this, SLOT(slotBgCBChecked(bool)) );
+    
+    //TODO Once the new canvas is complete, so something better, it does not worth it for now
+    if (m_UiWidgets.textColorB->color() == TEXT_COLOR) {
+        m_UiWidgets.textColorCB->setChecked(false);
+        m_UiWidgets.textColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.textColorCB->setChecked(true);
+    }
+
+    if (m_UiWidgets.fillColorB->color() == FILL_COLOR) {
+        m_UiWidgets.fillColorCB->setChecked(false);
+        m_UiWidgets.fillColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.fillColorCB->setChecked(true);
+    }
+    
+    if (m_UiWidgets.lineColorB->color() == LINK_COLOR) {
+        m_UiWidgets.lineColorCB->setChecked(false);
+        m_UiWidgets.lineColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.lineColorCB->setChecked(true);
+    }
 }
 
 void SettingsDlg::setupGeneralPage()
@@ -198,10 +241,11 @@ void SettingsDlg::setupGeneralPage()
     startupLayout->addWidget( m_GeneralWidgets.diagramKB, 1, 1 );
 
     // start at 1 because we don't allow No Diagram any more
-    // diagramNo 1 is Uml::dt_Class
-    // digaramNo 9 is Uml::dt_EntityRelationship
-    for (int diagramNo=1; diagramNo < 10; ++diagramNo) {
-        insertDiagram( Model_Utils::diagramTypeToString( ( Uml::Diagram_Type )diagramNo ), /*index*/ diagramNo - 1  );
+    // diagramNo 1 is Uml::DiagramType::Class
+    // digaramNo 9 is Uml::DiagramType::EntityRelationship
+    for (int diagramNo = 1; diagramNo < 10; ++diagramNo) {
+        Uml::DiagramType dt = Uml::DiagramType(Uml::DiagramType::Value(diagramNo));
+        insertDiagram( dt.toString(), diagramNo - 1  );
     }
 
     m_GeneralWidgets.diagramKB->setCurrentIndex( (int)m_pOptionState->generalState.diagram-1 );
@@ -215,8 +259,8 @@ void SettingsDlg::setupGeneralPage()
     startupLayout->addWidget( m_GeneralWidgets.languageKB, 2, 1 );
 
     int indexCounter = 0;
-    while (indexCounter < Uml::pl_Reserved) {
-        QString language = Model_Utils::progLangToString((Uml::Programming_Language) indexCounter);
+    while (indexCounter < Uml::ProgrammingLanguage::Reserved) {
+        QString language = Uml::ProgrammingLanguage::toString(Uml::ProgrammingLanguage::Value(indexCounter));
         m_GeneralWidgets.languageKB->insertItem(indexCounter, language);
         indexCounter++;
     }
@@ -326,6 +370,17 @@ void SettingsDlg::insertOperationScope( const QString& type, int index )
     m_ClassWidgets.m_pOperationScopeCB->completionObject()->addItem( type );
 }
 
+void SettingsDlg::setupCodeImportPage()
+{
+    //setup code importer settings page
+    KVBox * page = new KVBox();
+    pageCodeImport = new KPageWidgetItem( page,i18n("Code Importer") );
+    pageCodeImport->setHeader( i18n("Code Import Settings") );
+    pageCodeImport->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_CodeImport) );
+    addPage( pageCodeImport );
+    m_pCodeImportPage = new CodeImportOptionsPage(page);
+}
+
 void SettingsDlg::setupCodeGenPage()
 {
     //setup code generation settings page
@@ -356,7 +411,7 @@ void SettingsDlg::setupFontPage()
     pageFont->setHeader( i18n("Font Settings") );
     pageFont->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Font) );
     addPage( pageFont );
-    m_FontWidgets.chooser = new KFontChooser( page,  false, QStringList(), false);
+    m_FontWidgets.chooser = new KFontChooser( page,  KFontChooser::NoDisplayFlags, QStringList(), 0);
     m_FontWidgets.chooser->setFont( m_pOptionState->uiState.font );
 }
 
@@ -373,6 +428,7 @@ void SettingsDlg::slotOk()
     applyPage( pageGeneral);
     applyPage( pageUserInterface );
     applyPage( pageCodeViewer);
+    applyPage( pageCodeImport );
     applyPage( pageCodeGen );
     applyPage( pageFont );
     accept();
@@ -390,7 +446,7 @@ void SettingsDlg::slotDefault()
         m_GeneralWidgets.timeISB->setEnabled( true );
         m_GeneralWidgets.loadlastCB->setChecked( true );
         m_GeneralWidgets.diagramKB->setCurrentIndex( 0 );
-        m_GeneralWidgets.languageKB->setCurrentIndex( ( int )Model_Utils::stringToProgLang( "C++" ) );
+        m_GeneralWidgets.languageKB->setCurrentIndex( Uml::ProgrammingLanguage::Cpp );
     }
     else if ( current == pageFont )
     {
@@ -399,8 +455,9 @@ void SettingsDlg::slotDefault()
     else if ( current == pageUserInterface )
     {
         m_UiWidgets.useFillColorCB->setChecked( true );
-        m_UiWidgets.fillColorB->setColor( QColor( 255, 255, 192 ) );
-        m_UiWidgets.lineColorB->setColor( Qt::red );
+        m_UiWidgets.textColorB->setColor( TEXT_COLOR );
+        m_UiWidgets.fillColorB->setColor( FILL_COLOR );
+        m_UiWidgets.lineColorB->setColor( LINK_COLOR );
         m_UiWidgets.lineWidthB->setValue( 0 );
     }
     else if ( current == pageClass )
@@ -415,7 +472,14 @@ void SettingsDlg::slotDefault()
         m_ClassWidgets.m_pAttribScopeCB->setCurrentIndex(1); // Private
         m_ClassWidgets.m_pOperationScopeCB->setCurrentIndex(0); // Public
     }
-    else if (  current == pageCodeGen || current == pageCodeViewer )
+    else if (  current == pageCodeImport )
+    {
+        m_pCodeImportPage->setDefaults();
+    }
+    else if (  current == pageCodeGen )
+    {
+    }
+    else if ( current == pageCodeViewer )
     {
     }
 }
@@ -435,8 +499,8 @@ void SettingsDlg::applyPage( KPageWidgetItem*item )
         // retrieve Suffix setting from dialog entry
         m_pOptionState->generalState.autosavesuffix = m_GeneralWidgets.autosaveSuffixT->text();
         m_pOptionState->generalState.loadlast = m_GeneralWidgets.loadlastCB->isChecked();
-        m_pOptionState->generalState.diagram  = (Uml::Diagram_Type)(m_GeneralWidgets.diagramKB->currentIndex() + 1);
-        m_pOptionState->generalState.defaultLanguage = ( Uml::Programming_Language )( m_GeneralWidgets.languageKB->currentIndex()  );
+        m_pOptionState->generalState.diagram  = Uml::DiagramType::Value(m_GeneralWidgets.diagramKB->currentIndex() + 1);
+        m_pOptionState->generalState.defaultLanguage = Uml::ProgrammingLanguage::Value( m_GeneralWidgets.languageKB->currentIndex());
     }
     else if ( item == pageFont )
     {
@@ -446,8 +510,11 @@ void SettingsDlg::applyPage( KPageWidgetItem*item )
     {
         m_pOptionState->uiState.useFillColor = m_UiWidgets.useFillColorCB->isChecked();
         m_pOptionState->uiState.fillColor = m_UiWidgets.fillColorB->color();
+        m_pOptionState->uiState.textColor = m_UiWidgets.textColorB->color();
         m_pOptionState->uiState.lineColor = m_UiWidgets.lineColorB->color();
         m_pOptionState->uiState.lineWidth = m_UiWidgets.lineWidthB->value();
+        m_pOptionState->uiState.backgroundColor = m_UiWidgets.bgColorB->color();
+        m_pOptionState->uiState.gridDotColor = m_UiWidgets.gridColorB->color();
     }
     else if ( item == pageClass )
     {
@@ -458,9 +525,14 @@ void SettingsDlg::applyPage( KPageWidgetItem*item )
         m_pOptionState->classState.showAttSig = m_ClassWidgets.showAttSigCB->isChecked();
         m_pOptionState->classState.showOpSig = m_ClassWidgets.showOpSigCB->isChecked();
         m_pOptionState->classState.showPackage = m_ClassWidgets.showPackageCB->isChecked();
+        m_pOptionState->classState.showPublicOnly = m_ClassWidgets.showPublicOnlyCB->isChecked();
         m_pOptionState->classState.defaultAttributeScope = (Uml::Visibility::Value) m_ClassWidgets.m_pAttribScopeCB->currentIndex();
         m_pOptionState->classState.defaultOperationScope = (Uml::Visibility::Value) m_ClassWidgets.m_pOperationScopeCB->currentIndex();
     }
+    else if ( item == pageCodeImport )
+    {
+        m_pCodeImportPage->apply();
+    }
     else if ( item == pageCodeGen )
     {
         m_pCodeGenPage->apply();
@@ -472,14 +544,61 @@ void SettingsDlg::applyPage( KPageWidgetItem*item )
     }
 }
 
-void SettingsDlg::slotLineBClicked()
+void SettingsDlg::slotTextCBChecked(bool value)
 {
-    m_UiWidgets.lineColorB->setColor( Qt::red );
+    if (value == false) {
+        m_UiWidgets.textColorB->setColor( TEXT_COLOR );
+        m_UiWidgets.textColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.textColorB->setDisabled(false);
+    }
 }
 
-void SettingsDlg::slotFillBClicked()
+void SettingsDlg::slotLineCBChecked(bool value)
 {
-    m_UiWidgets.fillColorB->setColor( QColor(255, 255, 192) );
+    if (value == false) {
+        m_UiWidgets.lineColorB->setColor( LINK_COLOR );
+        m_UiWidgets.lineColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.lineColorB->setDisabled(false);
+    }
+}
+
+void SettingsDlg::slotFillCBChecked(bool value)
+{
+    if (value == false) {
+        m_UiWidgets.fillColorB->setColor( FILL_COLOR );
+        m_UiWidgets.fillColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.fillColorB->setDisabled(false);
+    }
+}
+
+void SettingsDlg::slotGridCBChecked(bool value)
+{
+    if (value == false) {
+        QPalette palette;
+        m_UiWidgets.gridColorB->setColor( palette.alternateBase().color() );
+        m_UiWidgets.gridColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.gridColorB->setDisabled(false);
+    }
+}
+
+void SettingsDlg::slotBgCBChecked(bool value)
+{
+    if (value == false) {
+        QPalette palette;
+        m_UiWidgets.bgColorB->setColor( palette.base().color() );
+        m_UiWidgets.bgColorB->setDisabled(true);
+    }
+    else {
+        m_UiWidgets.bgColorB->setDisabled(false);
+    }
 }
 
 void SettingsDlg::slotAutosaveCBClicked()
