@@ -1,21 +1,18 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2008                                               *
+ *   copyright (C) 2003-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "entity.h"
-// qt/kde includes
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+
 // app includes
+#include "debug_utils.h"
 #include "entityattribute.h"
 #include "uniqueconstraint.h"
 #include "foreignkeyconstraint.h"
@@ -25,27 +22,51 @@
 #include "uniqueid.h"
 #include "umlentityattributelist.h"
 #include "umlentityconstraintlist.h"
-#include "clipboard/idchangelog.h"
-#include "dialogs/umlentityattributedialog.h"
-#include "dialogs/umluniqueconstraintdialog.h"
-#include "dialogs/umlforeignkeyconstraintdialog.h"
-#include "dialogs/umlcheckconstraintdialog.h"
+#include "idchangelog.h"
+#include "umlentityattributedialog.h"
+#include "umluniqueconstraintdialog.h"
+#include "umlforeignkeyconstraintdialog.h"
+#include "umlcheckconstraintdialog.h"
 
-UMLEntity::UMLEntity(const QString& name, Uml::IDType id) : UMLClassifier(name, id)
+// kde includes
+#include <klocale.h>
+#include <kmessagebox.h>
+
+// qt includes
+#include <QtCore/QPointer>
+
+/**
+ * Constructor.
+ */
+UMLEntity::UMLEntity(const QString& name, Uml::IDType id)
+  : UMLClassifier(name, id),
+    m_PrimaryKey(0)
 {
-    init();
+    m_BaseType = UMLObject::ot_Entity;
+    connect(this, SIGNAL(entityAttributeRemoved(UMLClassifierListItem*)),
+            this, SLOT(slotEntityAttributeRemoved(UMLClassifierListItem*)));
 }
 
+/**
+ * Standard destructor.
+ */
 UMLEntity::~UMLEntity()
 {
     m_List.clear();
 }
 
-bool UMLEntity::operator==(const UMLEntity& rhs )
+/**
+ * Overloaded '==' operator.
+ */
+bool UMLEntity::operator==(const UMLEntity& rhs) const
 {
     return UMLClassifier::operator==(rhs);
 }
 
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
 void UMLEntity::copyInto(UMLObject *lhs) const
 {
     UMLEntity *target = static_cast<UMLEntity*>(lhs);
@@ -57,6 +78,9 @@ void UMLEntity::copyInto(UMLObject *lhs) const
     target->m_PrimaryKey = m_PrimaryKey;
 }
 
+/**
+ * Make a clone of this object.
+ */
 UMLObject* UMLEntity::clone() const
 {
     UMLEntity* clone = new UMLEntity();
@@ -65,22 +89,22 @@ UMLObject* UMLEntity::clone() const
     return clone;
 }
 
-void UMLEntity::init()
-{
-    m_BaseType = Uml::ot_Entity;
-    m_PrimaryKey = NULL;
-    connect( this,  SIGNAL( entityAttributeRemoved( UMLClassifierListItem* ) ),
-             this, SLOT( slotEntityAttributeRemoved( UMLClassifierListItem* ) ) );
-}
-
-UMLAttribute* UMLEntity::createAttribute(const QString &name /*=null*/, UMLObject *type /*=NULL*/
-                                         , Uml::Visibility vis /* = Uml::Visibility::Private*/
-                                         , const QString& iv /* = QString()*/)
+/**
+ * Create an UMLAttribute.
+ * @param name   an optional name for the attribute
+ * @param type   an optional type object for the attribute
+ * @param vis    the visibility of the attribute
+ * @param iv     the initial value for the attribute
+ * @return   the just created attribute or null 
+ */
+UMLAttribute* UMLEntity::createAttribute(const QString &name /*= QString()*/, UMLObject *type /*= 0*/,
+                                         Uml::Visibility vis /* = Uml::Visibility::Private*/,
+                                         const QString& iv /* = QString()*/)
 {
     Uml::IDType id = UniqueID::gen();
     QString currentName;
     if (name.isNull())  {
-        currentName = uniqChildName(Uml::ot_EntityAttribute);
+        currentName = uniqChildName(UMLObject::ot_EntityAttribute);
     } else {
         currentName = name;
     }
@@ -92,41 +116,48 @@ UMLAttribute* UMLEntity::createAttribute(const QString &name /*=null*/, UMLObjec
 
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
-    while (button==KDialog::Accepted && !goodName && name.isNull()) {
-        UMLEntityAttributeDialog attributedialog(0, newAttribute);
-        button = attributedialog.exec();
-        QString name = newAttribute->getName();
+    while (button == KDialog::Accepted && !goodName && name.isNull()) {
+        QPointer<UMLEntityAttributeDialog> dialog = new UMLEntityAttributeDialog(0, newAttribute);
+        button = dialog->exec();
+        QString name = newAttribute->name();
 
-        if(name.length() == 0) {
+        if (name.length() == 0) {
             KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
         } else if ( findChildObject(name) != NULL ) {
             KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
+        delete dialog;
     }
 
     if (button != KDialog::Accepted) {
         delete newAttribute;
-        return NULL;
+        return 0;
     }
 
     addEntityAttribute(newAttribute);
 
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     umldoc->signalUMLObjectCreated(newAttribute);
     return newAttribute;
 }
 
+/**
+ * Creates a Unique Constraint for this Entity.
+ * @param name   an optional name
+ * @return the UniqueConstraint created
+ */
 UMLUniqueConstraint* UMLEntity::createUniqueConstraint(const QString &name )
 {
     Uml::IDType id = UniqueID::gen();
     QString currentName;
     if (name.isNull())  {
+
         /**
          *  @todo check parameter
          */
-        currentName = uniqChildName(Uml::ot_UniqueConstraint);
+        currentName = uniqChildName(UMLObject::ot_UniqueConstraint);
     } else {
         currentName = name;
     }
@@ -138,18 +169,19 @@ UMLUniqueConstraint* UMLEntity::createUniqueConstraint(const QString &name )
 
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
-    while (button==KDialog::Accepted && !goodName && name.isNull()) {
-        UMLUniqueConstraintDialog uniqueConstraintDialog(0, newUniqueConstraint);
-        button = uniqueConstraintDialog.exec();
-        QString name = newUniqueConstraint->getName();
+    while (button == KDialog::Accepted && !goodName && name.isNull()) {
+        QPointer<UMLUniqueConstraintDialog> dialog = new UMLUniqueConstraintDialog(0, newUniqueConstraint);
+        button = dialog->exec();
+        QString name = newUniqueConstraint->name();
 
-        if(name.length() == 0) {
+        if (name.length() == 0) {
             KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
         } else if ( findChildObject(name) != NULL ) {
             KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
+        delete dialog;
     }
 
     if (button != KDialog::Accepted) {
@@ -159,18 +191,23 @@ UMLUniqueConstraint* UMLEntity::createUniqueConstraint(const QString &name )
 
     addConstraint(newUniqueConstraint);
 
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     umldoc->signalUMLObjectCreated(newUniqueConstraint);
     emitModified();
     return newUniqueConstraint;
 }
 
+/**
+ * Creates a Foreign Key  Constraint for this Entity.
+ * @param name   an optional name
+ * @return the ForeignKeyConstraint created
+ */
 UMLForeignKeyConstraint* UMLEntity::createForeignKeyConstraint(const QString &name )
 {
     Uml::IDType id = UniqueID::gen();
     QString currentName;
     if (name.isNull())  {
-        currentName = uniqChildName(Uml::ot_ForeignKeyConstraint);
+        currentName = uniqChildName(UMLObject::ot_ForeignKeyConstraint);
     } else {
         currentName = name;
     }
@@ -182,18 +219,19 @@ UMLForeignKeyConstraint* UMLEntity::createForeignKeyConstraint(const QString &na
 
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
-    while (button==KDialog::Accepted && !goodName && name.isNull()) {
-        UMLForeignKeyConstraintDialog foreignKeyConstraintDialog(0, newForeignKeyConstraint);
-        button = foreignKeyConstraintDialog.exec();
-        QString name = newForeignKeyConstraint->getName();
+    while (button == KDialog::Accepted && !goodName && name.isNull()) {
+        QPointer<UMLForeignKeyConstraintDialog> dialog = new UMLForeignKeyConstraintDialog(0, newForeignKeyConstraint);
+        button = dialog->exec();
+        QString name = newForeignKeyConstraint->name();
 
-        if(name.length() == 0) {
+        if (name.length() == 0) {
             KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
         } else if ( findChildObject(name) != NULL ) {
             KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
+        delete dialog;
     }
 
     if (button != KDialog::Accepted) {
@@ -202,19 +240,23 @@ UMLForeignKeyConstraint* UMLEntity::createForeignKeyConstraint(const QString &na
 
     addConstraint(newForeignKeyConstraint);
 
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     umldoc->signalUMLObjectCreated(newForeignKeyConstraint);
     emitModified();
     return newForeignKeyConstraint;
 }
 
-
+/**
+ * Creates a Check  Constraint for this Entity.
+ * @param name   an optional name
+ * @return the CheckConstraint created
+ */
 UMLCheckConstraint* UMLEntity::createCheckConstraint(const QString &name )
 {
     Uml::IDType id = UniqueID::gen();
     QString currentName;
     if (name.isNull())  {
-        currentName = uniqChildName(Uml::ot_CheckConstraint);
+        currentName = uniqChildName(UMLObject::ot_CheckConstraint);
     } else {
         currentName = name;
     }
@@ -226,18 +268,19 @@ UMLCheckConstraint* UMLEntity::createCheckConstraint(const QString &name )
 
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
-    while (button==KDialog::Accepted && !goodName && name.isNull()) {
-        UMLCheckConstraintDialog checkConstraintDialog(0, newCheckConstraint);
-        button = checkConstraintDialog.exec();
-        QString name = newCheckConstraint->getName();
+    while (button == KDialog::Accepted && !goodName && name.isNull()) {
+        QPointer<UMLCheckConstraintDialog> dialog = new UMLCheckConstraintDialog(0, newCheckConstraint);
+        button = dialog->exec();
+        QString name = newCheckConstraint->name();
 
-        if(name.length() == 0) {
+        if (name.length() == 0) {
             KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
         } else if ( findChildObject(name) != NULL ) {
             KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
+        delete dialog;
     }
 
     if (button != KDialog::Accepted) {
@@ -246,13 +289,19 @@ UMLCheckConstraint* UMLEntity::createCheckConstraint(const QString &name )
 
     addConstraint(newCheckConstraint);
 
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     umldoc->signalUMLObjectCreated(newCheckConstraint);
     emitModified();
     return newCheckConstraint;
 }
 
-
+/**
+ * Adds an entityAttribute.
+ * The entityAttribute object must not belong to any other concept.
+ * @param name   name of the UMLEntityAttribute
+ * @param id     id of the UMLEntityAttribute
+ * @return  True if the entityAttribute was successfully added.
+ */
 UMLObject* UMLEntity::addEntityAttribute(const QString& name, Uml::IDType id)
 {
     UMLEntityAttribute* literal = new UMLEntityAttribute(this, name, id);
@@ -263,67 +312,100 @@ UMLObject* UMLEntity::addEntityAttribute(const QString& name, Uml::IDType id)
     return literal;
 }
 
-bool UMLEntity::addEntityAttribute(UMLEntityAttribute* attribute, IDChangeLog* Log /* = 0*/)
+/**
+ * Adds an already created entityAttribute.
+ * The entityAttribute object must not belong to any other concept.
+ * @param att   Pointer to the UMLEntityAttribute.
+ * @param log   Pointer to the IDChangeLog.
+ * @return  True if the entityAttribute was successfully added.
+ */
+bool UMLEntity::addEntityAttribute(UMLEntityAttribute* att, IDChangeLog* log /* = 0*/)
 {
-    QString name = (QString)attribute->getName();
+    QString name = (QString)att->name();
     if (findChildObject(name) == NULL) {
-        attribute->setParent(this);
-        m_List.append(attribute);
-        emit entityAttributeAdded(attribute);
+        att->setParent(this);
+        m_List.append(att);
+        emit entityAttributeAdded(att);
         UMLObject::emitModified();
-        connect(attribute,SIGNAL(modified()),this,SIGNAL(modified()));
+        connect(att, SIGNAL(modified()), this, SIGNAL(modified()));
         return true;
-    } else if (Log) {
-        Log->removeChangeByNewID( attribute->getID() );
-        delete attribute;
+    } else if (log) {
+        log->removeChangeByNewID( att->id() );
+        delete att;
     }
     return false;
 }
 
-bool UMLEntity::addEntityAttribute(UMLEntityAttribute* attribute, int position)
+/**
+ * Adds an entityAttribute to the entity, at the given position.
+ * If position is negative or too large, the entityAttribute is added
+ * to the end of the list.
+ * TODO:  give default value -1 to position (append) - now it conflicts with the method above..
+ * @param att       Pointer to the UMLEntityAttribute.
+ * @param position  Position index for the insertion.
+ * @return  True if the entityAttribute was successfully added.
+ */
+bool UMLEntity::addEntityAttribute(UMLEntityAttribute* att, int position)
 {
-    QString name = (QString)attribute->getName();
+    QString name = (QString)att->name();
     if (findChildObject(name) == NULL) {
-        attribute->setParent(this);
+        att->setParent(this);
         if ( position >= 0 && position <= (int)m_List.count() )  {
-            m_List.insert(position,attribute);
+            m_List.insert(position, att);
         } else {
-            m_List.append(attribute);
+            m_List.append(att);
         }
-        emit entityAttributeAdded(attribute);
+        emit entityAttributeAdded(att);
         UMLObject::emitModified();
-        connect(attribute,SIGNAL(modified()),this,SIGNAL(modified()));
+        connect(att, SIGNAL(modified()), this, SIGNAL(modified()));
         return true;
     }
     return false;
 }
 
-int UMLEntity::removeEntityAttribute(UMLClassifierListItem* literal)
+/**
+ * Removes an entityAttribute from the class.
+ * @param att   The entityAttribute to remove.
+ * @return  Count of the remaining entityAttributes after removal.
+ *          Returns -1 if the given entityAttribute was not found.
+ */
+int UMLEntity::removeEntityAttribute(UMLClassifierListItem* att)
 {
-    if (!m_List.removeAll((UMLEntityAttribute*)literal)) {
+    if (!m_List.removeAll((UMLEntityAttribute*)att)) {
         uDebug() << "can not find att given in list";
         return -1;
     }
-    emit entityAttributeRemoved(literal);
+    emit entityAttributeRemoved(att);
     UMLObject::emitModified();
     // If we are deleting the object, then we don't need to disconnect..this is done auto-magically
     // for us by QObject. -b.t.
-    // disconnect(a,SIGNAL(modified()),this,SIGNAL(modified()));
-    delete literal;
+    // disconnect(att, SIGNAL(modified()), this, SIGNAL(modified()));
+    delete att;
     return m_List.count();
 }
 
+/**
+ * Returns the number of entityAttributes for the class.
+ * @return  The number of entityAttributes for the class.
+ */
 int UMLEntity::entityAttributes()
 {
-    UMLClassifierListItemList entityAttributes = getFilteredList(Uml::ot_EntityAttribute);
+    UMLClassifierListItemList entityAttributes = getFilteredList(UMLObject::ot_EntityAttribute);
     return entityAttributes.count();
 }
 
+/**
+ * Emit the entityAttributeRemoved signal.
+ */
 void UMLEntity::signalEntityAttributeRemoved(UMLClassifierListItem *eattr)
 {
     emit entityAttributeRemoved(eattr);
 }
 
+/**
+ * Resolve the types referenced by our UMLEntityAttributes.
+ * Reimplements the method from UMLClassifier.
+ */
 bool UMLEntity::resolveRef()
 {
     bool success = UMLClassifier::resolveRef();
@@ -331,12 +413,12 @@ bool UMLEntity::resolveRef()
         UMLObject* obj = oit.next();
         if (obj->resolveRef()) {
             UMLClassifierListItem *cli = static_cast<UMLClassifierListItem*>(obj);
-            switch (cli->getBaseType() ) {
-                case Uml::ot_EntityAttribute:
+            switch (cli->baseType() ) {
+                case UMLObject::ot_EntityAttribute:
                     emit entityAttributeAdded(cli);
                     break;
-                case Uml::ot_UniqueConstraint:
-                case Uml::ot_ForeignKeyConstraint:
+                case UMLObject::ot_UniqueConstraint:
+                case UMLObject::ot_ForeignKeyConstraint:
                     emit entityConstraintAdded(cli);
                     break;
                 default:
@@ -347,17 +429,20 @@ bool UMLEntity::resolveRef()
     return success;
 }
 
+/**
+ * Creates the <UML:Entity> element including its entityliterals.
+ */
 void UMLEntity::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
     QDomElement entityElement = UMLObject::save("UML:Entity", qDoc);
     //save operations
-    UMLClassifierListItemList entityAttributes = getFilteredList(Uml::ot_EntityAttribute);
+    UMLClassifierListItemList entityAttributes = getFilteredList(UMLObject::ot_EntityAttribute);
     UMLClassifierListItem* pEntityAttribute = 0;
     foreach (pEntityAttribute, entityAttributes) {
         pEntityAttribute->saveToXMI(qDoc, entityElement);
     }
 
-    UMLClassifierListItemList entityConstraints = getFilteredList(Uml::ot_EntityConstraint);
+    UMLClassifierListItemList entityConstraints = getFilteredList(UMLObject::ot_EntityConstraint);
     foreach(UMLClassifierListItem* cli, entityConstraints) {
         cli->saveToXMI(qDoc,entityElement);
     }
@@ -365,6 +450,9 @@ void UMLEntity::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
     qElement.appendChild(entityElement);
 }
 
+/**
+ * Loads the <UML:Entity> element including its entityAttributes.
+ */
 bool UMLEntity::load(QDomElement& element)
 {
     QDomNode node = element.firstChild();
@@ -375,26 +463,26 @@ bool UMLEntity::load(QDomElement& element)
         }
         QDomElement tempElement = node.toElement();
         QString tag = tempElement.tagName();
-        if (Uml::tagEq(tag, "EntityAttribute")) {   // for backward compatibility
+        if (UMLDoc::tagEq(tag, "EntityAttribute")) {   // for backward compatibility
             UMLEntityAttribute* pEntityAttribute = new UMLEntityAttribute(this);
             if( !pEntityAttribute->loadFromXMI(tempElement) ) {
                 return false;
             }
             m_List.append(pEntityAttribute);
-        } else if ( Uml::tagEq( tag, "UniqueConstraint" ) ) {
+        } else if ( UMLDoc::tagEq( tag, "UniqueConstraint" ) ) {
             UMLUniqueConstraint* pUniqueConstraint = new UMLUniqueConstraint(this);
             if ( !pUniqueConstraint->loadFromXMI(tempElement) ) {
                 return false;
             }
             addConstraint( pUniqueConstraint );
-        } else if ( Uml::tagEq( tag,"ForeignKeyConstraint" ) ) {
+        } else if ( UMLDoc::tagEq( tag,"ForeignKeyConstraint" ) ) {
             UMLForeignKeyConstraint* pForeignKeyConstraint = new UMLForeignKeyConstraint(this);
             if ( !pForeignKeyConstraint->loadFromXMI(tempElement) ) {
                 return false;
             }
 
             addConstraint( pForeignKeyConstraint );
-        } else if ( Uml::tagEq( tag, "CheckConstraint" ) ) {
+        } else if ( UMLDoc::tagEq( tag, "CheckConstraint" ) ) {
 
             UMLCheckConstraint* pCheckConstraint = new UMLCheckConstraint( this );
             if ( !pCheckConstraint->loadFromXMI( tempElement ) ) {
@@ -403,7 +491,7 @@ bool UMLEntity::load(QDomElement& element)
 
             addConstraint( pCheckConstraint );
         } else if (tag == "stereotype") {
-            uDebug() << m_Name << ": losing old-format stereotype.";
+            uDebug() << name() << ": losing old-format stereotype.";
         } else {
             uWarning() << "unknown child type in UMLEntity::load";
         }
@@ -412,24 +500,30 @@ bool UMLEntity::load(QDomElement& element)
     return true;
 }
 
-
+/**
+ * Sets the UniqueConstraint passed as the Primary Key of this Entity
+ * If the UniqueConstraint exists, then it is made a primary key
+ * Else the UniqueConstraint is added and set as PrimaryKey
+ * @param uconstr The Unique Constraint that is  to be set as Primary Key
+ * @return true if Primary key could be set successfully
+ */
 bool UMLEntity::setAsPrimaryKey(UMLUniqueConstraint* uconstr)
 {
     if ( uconstr == NULL ) {
-        uDebug()<<"NULL value passed. To unset a Primary Key use "
-                <<"unsetPrimaryKey()";
+        uDebug() << "NULL value passed. To unset a Primary Key use "
+                 << "unsetPrimaryKey()";
         return false;
     }
 
     if ( static_cast<UMLEntity*>( uconstr->parent() ) != this ) {
 
-        uDebug()<<"Parent of "<<uconstr->getName()
-                <<" does not match with current entity";
+        uDebug() << "Parent of " << uconstr->name()
+                 << " does not match with current entity";
         return false;
     }
 
     // check if this constraint already exists as a unique constraint for this entity
-    UMLUniqueConstraint* uuc = static_cast<UMLUniqueConstraint*>( findChildObjectById( uconstr->getID() ) );
+    UMLUniqueConstraint* uuc = static_cast<UMLUniqueConstraint*>( findChildObjectById( uconstr->id() ) );
     if ( uuc == NULL ) {
         addConstraint( uconstr );
         uuc = uconstr;
@@ -439,7 +533,7 @@ bool UMLEntity::setAsPrimaryKey(UMLUniqueConstraint* uconstr)
 
     m_PrimaryKey = uuc;
 
-    if ( oldPrimaryKey!= NULL )
+    if ( oldPrimaryKey != NULL )
         oldPrimaryKey->emitModified();
 
     uuc->emitModified();
@@ -447,25 +541,40 @@ bool UMLEntity::setAsPrimaryKey(UMLUniqueConstraint* uconstr)
     return true;
 }
 
+/**
+ * Unset a Primary Key Constraint if it exists, else does nothing
+ * This function will make the primary key into just another UniqueConstraint
+ * if it exists
+ */
 void UMLEntity::unsetPrimaryKey()
 {
-    m_PrimaryKey = NULL;
+    m_PrimaryKey = 0;
 }
 
+/**
+ * Checks if This UMLEntity has a primary key set.
+ * @return true if a Primary Key Exists for this UMLEntity
+ */
 bool UMLEntity::hasPrimaryKey() const
 {
-    if ( m_PrimaryKey == NULL ) {
-        return false;
+    if (m_PrimaryKey) {
+        return true;
     }
 
-    return true;
+    return false;
 }
 
+/**
+ * Adds a Constraint to this UMLEntity.
+ * To set a UMLUniqueConstraint as Primary Key use setAsPrimaryKey.
+ * @param constr The UMLEntityConstraint that is to be added
+ * @return true if the constraint could be added successfully
+ */
 bool UMLEntity::addConstraint(UMLEntityConstraint* constr)
 {
-    if ( findChildObjectById( constr->getID() ) != NULL ) {
-        uDebug()<<"Constraint with id "<<ID2STR(constr->getID())
-                <<" already exists ";
+    if ( findChildObjectById( constr->id() ) != NULL ) {
+        uDebug() << "Constraint with id " << ID2STR(constr->id())
+                 << " already exists ";
         return false;
     }
 
@@ -478,11 +587,17 @@ bool UMLEntity::addConstraint(UMLEntityConstraint* constr)
     return true;
 }
 
+/**
+ * Removes an existing constraint from this UMLEntity.
+ * If the Contraint is a Primary Key, this Entity will no longer have a PrimaryKey.
+ * @param constr   the constraint to be removed
+ * @return true if the constraint could be removed successfully
+ */
 bool UMLEntity::removeConstraint(UMLEntityConstraint* constr)
 {
-     if ( findChildObjectById( constr->getID() ) == NULL ) {
-        uDebug()<<"Constraint with id "<<ID2STR(constr->getID())
-                <<" does not exist ";
+     if ( findChildObjectById( constr->id() ) == NULL ) {
+        uDebug() << "Constraint with id " << ID2STR(constr->id())
+                 << " does not exist ";
         return false;
     }
 
@@ -499,6 +614,9 @@ bool UMLEntity::removeConstraint(UMLEntityConstraint* constr)
     return true;
 }
 
+/**
+ * Slot for entity attribute removed.
+ */
 void UMLEntity::slotEntityAttributeRemoved(UMLClassifierListItem* cli)
 {
     // this function does some cleanjobs related to this entity when the attribute is
@@ -506,12 +624,11 @@ void UMLEntity::slotEntityAttributeRemoved(UMLClassifierListItem* cli)
 
     UMLEntityAttribute* entAtt = static_cast<UMLEntityAttribute*>( cli );
     if ( cli ) {
-       UMLClassifierListItemList ual = this->getFilteredList(Uml::ot_UniqueConstraint);
+       UMLClassifierListItemList ual = this->getFilteredList(UMLObject::ot_UniqueConstraint);
 
        foreach( UMLClassifierListItem* ucli,  ual ) {
            UMLUniqueConstraint* uuc = static_cast<UMLUniqueConstraint*>( ucli );
            if ( uuc->hasEntityAttribute( entAtt ) ) {
-
                uuc->removeEntityAttribute(entAtt );
            }
        }
@@ -519,13 +636,16 @@ void UMLEntity::slotEntityAttributeRemoved(UMLClassifierListItem* cli)
 
 }
 
-UMLClassifierListItemList UMLEntity::getFilteredList(Uml::Object_Type ot) const
+/**
+ * Reimplementation of getFilteredList to support ot=UMLObject::ot_EntityConstraint.
+ */
+UMLClassifierListItemList UMLEntity::getFilteredList(UMLObject::ObjectType ot) const
 {
-    if ( ot == Uml::ot_EntityConstraint ) {
+    if ( ot == UMLObject::ot_EntityConstraint ) {
         UMLClassifierListItemList ucList,fcList,ccList, rcList;
-        ucList = UMLClassifier::getFilteredList( Uml::ot_UniqueConstraint );
-        fcList = UMLClassifier::getFilteredList( Uml::ot_ForeignKeyConstraint );
-        ccList = UMLClassifier::getFilteredList( Uml::ot_CheckConstraint );
+        ucList = UMLClassifier::getFilteredList( UMLObject::ot_UniqueConstraint );
+        fcList = UMLClassifier::getFilteredList( UMLObject::ot_ForeignKeyConstraint );
+        ccList = UMLClassifier::getFilteredList( UMLObject::ot_CheckConstraint );
 
         // append the lists to rcList
         // first the Unique Constraints
@@ -544,12 +664,15 @@ UMLClassifierListItemList UMLEntity::getFilteredList(Uml::Object_Type ot) const
 
         return rcList;
     } else {
-
         return UMLClassifier::getFilteredList( ot );
-
     }
 }
 
+/**
+ * Checks if a given Unique Constraint is primary key of this entity
+ * @param uConstr   a Unique Constraint
+ * @return bool true if passed parameter is a primary key of this entity
+ */
 bool UMLEntity::isPrimaryKey(UMLUniqueConstraint* uConstr) const
 {
     if ( uConstr == m_PrimaryKey ) {
@@ -559,12 +682,16 @@ bool UMLEntity::isPrimaryKey(UMLUniqueConstraint* uConstr) const
     return false;
 }
 
+/**
+ * Returns the Entity Attributes.
+ * Same as getFilteredList(UMLObject::ot_EntityAttribute).
+ */
 UMLEntityAttributeList UMLEntity::getEntityAttributes() const
 {
     UMLEntityAttributeList entityAttributeList;
     for (UMLObjectListIt lit(m_List); lit.hasNext(); ) {
         UMLObject *listItem = lit.next();
-        if (listItem->getBaseType() == Uml::ot_EntityAttribute) {
+        if (listItem->baseType() == UMLObject::ot_EntityAttribute) {
             entityAttributeList.append(static_cast<UMLEntityAttribute*>(listItem));
         }
     }
@@ -572,10 +699,18 @@ UMLEntityAttributeList UMLEntity::getEntityAttributes() const
 }
 
 
+/**
+ * Create a new ClassifierListObject (entityattribute)
+ * according to the given XMI tag.
+ * Returns NULL if the string given does not contain one of the tags
+ * <UML:EntityAttribute>
+ * Used by the clipboard for paste operation.
+ * Reimplemented from UMLClassifier for UMLEntity
+ */
 UMLClassifierListItem* UMLEntity::makeChildObject(const QString& xmiTag)
 {
     UMLClassifierListItem* pObject = NULL;
-    if (Uml::tagEq(xmiTag, "EntityAttribute")) {
+    if (UMLDoc::tagEq(xmiTag, "EntityAttribute")) {
         pObject = new UMLEntityAttribute(this);
     }
     return pObject;
